#
# spec file for package kcov
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           kcov
Version:        42
Release:        bp160.1.7
Summary:        Code coverage tool without special compilation options
License:        APSL-2.0 AND GPL-2.0-only
Group:          Development/Tools/Other
URL:            https://github.com/SimonKagstrom/kcov
Source0:        https://github.com/SimonKagstrom/kcov/archive/v%{version}.tar.gz
Patch0:         link_order.patch
BuildRequires:  binutils-devel
BuildRequires:  c++_compiler
BuildRequires:  cmake
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(libdw)
BuildRequires:  pkgconfig(libelf)
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(zlib)
ExcludeArch:    s390x

%description
Kcov is a code coverage tester for compiled programs, Python scripts and shell
scripts.  It allows collecting code coverage information from executables
without special command-line arguments, and continuously produces output from
long-running applications.

%prep
%autosetup -p1
# remove LLDB headers bundled for MacOS
rm -frv external/

%build
%if 0%{?suse_version} > 1500 || (0%{?suse_version} == 1500 && 0%{?sle_version} > 150400)
export CFLAGS="%{optflags} -lsframe -lzstd"
%endif
%cmake
%cmake_build

%install
%cmake_install
# ignore ChangeLog and COPYING*, they are handled with doc and license macros
rm -r %{buildroot}%{_datadir}/doc/kcov

%files
%doc ChangeLog README.md
%license COPYING*
%{_bindir}/kcov
%{_bindir}/kcov-system-daemon
%{_mandir}/man1/kcov.1%{?ext_man}

%changelog
* Tue Apr 16 2024 Lubos Kocman <lubos.kocman@suse.com>
- legaldb scan: Add APSL-2.0
  for kcov-42/src/engines/osx/mach_exc.defs
* Mon Apr 15 2024 Max Lin <mlin@suse.com>
- Add -lsframe, -lzstd to build flags on Leap 15.5 and 15.6 build
* Mon Apr  1 2024 jun wang <jgwang@suse.com>
- Update to version 42
  * Issue #317: Correct handling of large amounts of solib data
  * Issue #399: Suppor for the LoongArch architecture
  * Issue #397: Correct symlinks if the out-directory is a
    relative path
  * OSX: Replace the lldb-engine/parser with a macho-parser and a
    mach-engine for improved performance (~20x)
* Mon Apr 24 2023 Antoine Belvire <antoine.belvire@opensuse.org>
- Update to 41:
  * Output the codecov file format.
  * Fix handling of symlinks.
  * Add support for RISC-V.
  * Fix gcc-13 build.
  * Correct the license for Debian.
  * Add --cobertura-only output option.
  * Fix build with binutils >= 2.39.
  * Clear BFD state between files to avoid breakpoint trashing atomic
    instructions.
- Remove kcov-40-binutils-2.39.patch: Fixed upstream.
- Add -lsframe, -lzstd to build flags: Fix linking.
* Thu Sep 22 2022 Antoine Belvire <antoine.belvire@opensuse.org>
- Update to 40:
  * Make libbfd non-required to avoid GPLv3
- Changes from 39:
  * Allow an address to map to multiple lines in the binary
    (gh#SimonKagstrom/kcov/366).
  * Correct abort signal return value (gh#SimonKagstrom/kcov/314).
  * Escape json URLs (gh#SimonKagstrom/kcov/353).
  * Match ELF perfect if it has the ELF magic
    (gh#SimonKagstrom/kcov/339).
  * Correct --collect-only, --report-only on non-identical
    machines (gh#SimonKagstrom/kcov/342)
  * Auto build via github actions (gh#SimonKagstrom/kcov/347).
  * Allow regex in --replace-src-path (gh#SimonKagstrom/kcov/333).
  * bash: Set PS4 in bash_helper for modern bashes to allow root
    usage (gh#SimonKagstrom/kcov/331).
  * Fix --merge with two --collect-only runs
    (gh#SimonKagstrom/kcov/327).
  * bash: Add --bash-tracefd-cloexec to avoid leaking trace fd
    to children (gh#SimonKagstrom/kcov/325).
  * bash: Drain stdout when on xtrace-fd
    (gh#SimonKagstrom/kcov/323).
  * Make kcov conan-ready (gh#SimonKagstrom/kcov/322).
- Add kcov-40-binutils-2.39.patch: Fix build with binutils 2.39
  (gh#SimonKagstrom/kcov#381, gh#SimonKagstrom/kcov!383).
- Refresh spec file.
- Remove unneeded build dependency on python3.
* Sun Jun 26 2022 Berthold Gunreben <azouhr@opensuse.org>
- solib-parser/lib.c:99:3: error: #error Unsupported architecture
  Disable s390x builds.
* Thu Sep 17 2020 Dirk Mueller <dmueller@suse.com>
- update to 38:
  This release fixes a kcov hang on the Aarch64 (ARM64) platform
  The Cobertura writer now supports the coverage-04.dtd version of the standard
- remove python3.patch (upstream):
* Sat May 18 2019 Doug Miller <dgm816@gmail.com>
- updated to use python3 when compiling via python3.patch which
  removes python2 need
* Fri May 10 2019 Doug Miller <dgm816@gmail.com>
- modernize spec file
  * updated to Release: 3
  * converted Source: to Source0: for verification check
  * converted Patch: to Patch0:
  * added BuildRoot: per openSUSE recomendations
  * split BuildRequires: across multiple lines
- converted patch to -p1 per openSUSE recommendations
* Wed May  8 2019 Doug Miller <dgm816@gmail.com>
- initial spec file based on fedora project:
  https://src.fedoraproject.org/rpms/kcov/blob/master/f/kcov.spec
